Package 'rk.cSplit'
| Title: |
An RKWard plugin to split concatenated columns into a long or
wide format using the cSplit() function from the
'splitstackshape' package. |
| Description: |
An RKWard plugin to split concatenated columns into a long
or wide format using the cSplit() function from the
'splitstackshape' package. |
| Authors: |
Alfonso Cano Robles |
| Maintainer: |
Alfonso Cano Robles <[email protected]> |
| License: |
GPL (>= 3) |
| Version: |
0.01.10 |
| Built: |
2026-06-05 06:24:27 UTC |
| Source: |
https://github.com/AlfCano/rk.cSplit |
Help Index